Produces plots of residuals for assumption checking of linear (mixed) models.
resplt(model.obj, shapiro = TRUE, call = FALSE, label.size = 10,
axes.size = 10, call.size = 9, mod.obj)A list containing ggplot2 objects which are diagnostic plots.
An aov, lm, lme (nlme::lme()), lmerMod (lme4::lmer()), asreml or mmer (sommer) model object.
(Logical) Display the Shapiro-Wilks test of normality on the plot?
(Logical) Display the model call on the plot?
A numeric value for the size of the axes label font size in points.
A numeric value for the size of the label (A,B,C) font point size.
A numeric value for the size of the model displayed on the plot.
Deprecated to be consistent with other functions. Please use model.obj instead.
biometryassist-deprecated